@@ -85,8 +85,9 @@ class DatazillaPerfPoster(object):
             'navigator.mozWifiManager.macAddress;')
 
         self.submit_report = True
-        self.ancillary_data = {}
-        self.ancillary_data['generated_by'] = 'b2gperf %s' % __version__
+        self.ancillary_data = {
+            'generated_by': 'b2gperf %s' % __version__,
+            'build_url': datazilla_config['build_url']}
 
         self.device = gaiatest.GaiaDevice(self.marionette)
         dm = mozdevice.DeviceManagerADB()
@@ -105,20 +106,20 @@ class DatazillaPerfPoster(object):
             'device_firmware_date')
 
         self.required = {
-            'generated by': self.ancillary_data.get('generated_by'),
-            'gaia revision': self.ancillary_data.get('gaia_revision'),
-            'gecko repository': self.ancillary_data.get('gecko_repository'),
-            'gecko revision': self.ancillary_data.get('gecko_revision'),
-            'build revision': self.ancillary_data.get('build_revision'),
+            'generated_by': self.ancillary_data.get('generated_by'),
+            'gaia_revision': self.ancillary_data.get('gaia_revision'),
+            'gecko_repository': self.ancillary_data.get('gecko_repository'),
+            'gecko_revision': self.ancillary_data.get('gecko_revision'),
+            'build_revision': self.ancillary_data.get('build_revision'),
             'protocol': datazilla_config['protocol'],
             'host': datazilla_config['host'],
             'project': datazilla_config['project'],
             'branch': datazilla_config['branch'],
-            'oauth key': datazilla_config['oauth_key'],
-            'oauth secret': datazilla_config['oauth_secret'],
-            'machine name': datazilla_config['machine_name'] or mac_address,
-            'device name': datazilla_config['device_name'],
-            'os version': settings.get('deviceinfo.os'),
+            'oauth_key': datazilla_config['oauth_key'],
+            'oauth_secret': datazilla_config['oauth_secret'],
+            'machine_name': datazilla_config['machine_name'] or mac_address,
+            'device_name': datazilla_config['device_name'],
+            'os_version': settings.get('deviceinfo.os'),
             'id': settings.get('deviceinfo.platform_build_id')}
 
         for key, value in self.required.items():
@@ -128,6 +129,10 @@ class DatazillaPerfPoster(object):
                 self.submit_report = False
                 self.logger.warn('Missing required DataZilla field: %s' % key)
 
+        for key, value in self.ancillary_data.items():
+            if value and key not in self.required.keys():
+                self.logger.debug('Ancillary field: %s (%s)' % (key, value))
+
         if not self.submit_report:
             self.logger.info('Reports will not be submitted to DataZilla')
 
@@ -142,11 +147,11 @@ class DatazillaPerfPoster(object):
             protocol=self.required.get('protocol'),
             host=self.required.get('host'),
             project=self.required.get('project'),
-            oauth_key=self.required.get('oauth key'),
-            oauth_secret=self.required.get('oauth secret'),
-            machine_name=self.required.get('machine name'),
+            oauth_key=self.required.get('oauth_key'),
+            oauth_secret=self.required.get('oauth_secret'),
+            machine_name=self.required.get('machine_name'),
             os='Firefox OS',
-            os_version=self.required.get('os version'),
+            os_version=self.required.get('os_version'),
             platform='Gonk',
             build_name='B2G',
             version='prerelease',
@@ -159,7 +164,7 @@ class DatazillaPerfPoster(object):
         for dataset in req.datasets():
             dataset['test_build'].update(self.ancillary_data)
             dataset['test_machine'].update(
-                {'type': self.required.get('device name')})
+                {'type': self.required.get('device_name')})
             self.logger.info('Submitting results to DataZilla: %s' % dataset)
             response = req.send(dataset)
             self.logger.info('Response: %s' % response.read())
@@ -175,6 +180,7 @@ class B2GPerfRunner(DatazillaPerfPoster):
         self.test_type = kwargs.pop('test_type')
         self.testvars = kwargs.pop('testvars', {})
         self.reset = kwargs.pop('reset')
+        self.start_timeout = kwargs.pop('start_timeout')
 
         DatazillaPerfPoster.__init__(self, *args, **kwargs)
         # Add various attributes to the report
@@ -224,7 +230,7 @@ class B2GPerfRunner(DatazillaPerfPoster):
             test = test_class(self.marionette, app_name, self.logger,
                               self.iterations, self.delay, self.device,
                               self.restart, self.settle_time, self.testvars,
-                              self.reset)
+                              self.reset, self.start_timeout)
             try:
                 test.run()
 
@@ -251,7 +257,7 @@ class B2GPerfRunner(DatazillaPerfPoster):
 class B2GPerfTest(object):
 
     def __init__(self, marionette, app_name, logger, iterations, delay,
-                 device, restart, settle_time, testvars, reset):
+                 device, restart, settle_time, testvars, reset, start_timeout):
         self.marionette = marionette
         self.app_name = app_name
         self.logger = logger
@@ -262,6 +268,7 @@ class B2GPerfTest(object):
         self.settle_time = settle_time
         self.testvars = testvars
         self.reset = reset
+        self.start_timeout = start_timeout
         self.requires_connection = False
         self.b2gpopulate = B2GPopulate(self.marionette)
 
@@ -305,7 +312,7 @@ class B2GPerfTest(object):
 
         if self.restart:
             self.logger.debug('Starting B2G')
-            self.device.start_b2g()
+            self.device.start_b2g(self.start_timeout)
 
         self.apps = gaiatest.GaiaApps(self.marionette)
         self.data_layer = gaiatest.GaiaData(self.marionette)
@@ -815,6 +822,11 @@ class dzOptionParser(OptionParser):
                         dest='datazilla_secret',
                         metavar='str',
                         help='oauth secret for datazilla server')
+        self.add_option('--dz-build-url',
+                        action='store',
+                        dest='datazilla_build_url',
+                        metavar='str',
+                        help='url of the build generating the results')
         self.add_option('--sources',
                         action='store',
                         dest='sources',
@@ -836,7 +848,8 @@ class dzOptionParser(OptionParser):
             'machine_name': options.datazilla_machine_name,
             'device_name': options.datazilla_device_name,
             'oauth_key': options.datazilla_key,
-            'oauth_secret': options.datazilla_secret}
+            'oauth_secret': options.datazilla_secret,
+            'build_url': options.datazilla_build_url}
         return datazilla_config
 
 
@@ -877,6 +890,13 @@ def cli():
                       metavar='float',
                       help='time to wait before initial launch '
                            '(default: %default)')
+    parser.add_option('--start-timeout',
+                      action='store',
+                      type=int,
+                      dest='start_timeout',
+                      default=60,
+                      metavar='int',
+                      help='b2g start timeout in seconds (default: %default)')
     parser.add_option('--test-type',
                       action='store',
                       type='str',
@@ -939,7 +959,8 @@ def cli():
                             settle_time=options.settle_time,
                             test_type=options.test_type,
                             testvars=testvars,
-                            reset=options.reset)
+                            reset=options.reset,
+                            start_timeout=options.start_timeout)
     b2gperf.measure_app_perf(args)
 
 
